@@ -6,15 +6,22 @@ AIS.py - A Python interface for the Swisscom All-in Signing Service.
 :license: AGPLv3, see README and LICENSE for more details
 
 """
-from .ais import AIS, Signature
+from .ais import AIS
 from .pdf import PDF
 from .exceptions import (
     AISError,
     AuthenticationFailed,
+    SignatureTooLarge,
     UnknownAISError,
 )
 
-__all__ = ('AIS', 'Signature', 'PDF', 'AISError',
-           'AuthenticationFailed', 'UnknownAISError')
+__all__ = (
+    'AIS',
+    'PDF',
+    'AISError',
+    'AuthenticationFailed',
+    'SignatureTooLarge',
+    'UnknownAISError'
+)
 
-__version__ = '2.0.0'
+__version__ = '2.1.1'
